package Email::Blaster;

use strict;
use warnings 'all';

our $VERSION = '0.0001_01';

__END__

=pod

=head1 NAME

Email::Blaster - Scalable Mass Email System

=head1 SYNOPSIS

TBD

=head1 DESCRIPTION

TBD

=head1 AUTHOR

John Drago <jdrago_999@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 by John Drago

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.0 or,
at your option, any later version of Perl 5 you may have available.

=cut
